@@ -17,7 +17,7 @@ def login(project, retries=2):
     resp = push_json(url, {'username': usr, 'password': pwd}, None)
     logging.debug(resp.json())
     if resp.status_code in (401, 402):
-        print 'Sorry. Try again.'
+        print('Sorry. Try again.')
         return login(project, retries-1)
     return usr, resp.json()['session_id']
 
