@@ -28,7 +28,7 @@ def push(project, message):
         container.print_log()
         exit("Push command failed")
     config = {'Cmd': project.sdk_runner_command, 'Entrypoint': project.docker_entrypoint}
-    container.load_credentials(renew=True)
+    container.load_credentials()
     container.commit(message, config).push()
     push_schema(project, container)
     container.remove()
