@@ -7,8 +7,12 @@ from sbdk.auth import login
 from sbdk.error import SbdkError
 
 
+def dockerize(username):
+    return ''.join([c.lower() if c.isalnum() else '_' for c in username.decode('utf-8').encode('idna')])
+
+
 def repo_name(project, user):
-    ret = project.docker_registry_name + '/' + user + '/' + project.name
+    ret = project.docker_registry_name + '/' + dockerize(user) + '/' + project.name
     return ret
 
 
